@@ -53,7 +53,7 @@ _DL_SYNTAX = types.SimpleNamespace(
 
 def _simple_short_form_provider(e: OWLEntity) -> str:
     iri: IRI = e.iri
-    sf = iri.reminder
+    sf = iri.remainder
     for ns in [namespaces.XSD, namespaces.OWL, namespaces.RDFS, namespaces.RDF]:
         if iri.get_namespace() == ns:
             return "%s:%s" % (ns.prefix, sf)
